module directions
! 
! Name the directions of the stencil with more meaningful names and to avoid
! always having to refer to the following diagram.
!
! For the linear PDE
!
!     au_xx + bu_yy + cu_z + du_y + eu = f
!
! on the unit square, where all of a - f are functions of (x,y), give the values for
! the stencil oriented in the standard position:
!
!
!	                    st(5)
!	                     |
!	                     |  
!	                     |
!	                     |
!	                     |
!	                     | 
!	  st(2) ----------- st(1) ---------- st(4)
!	                     |
!	                     |
!	                     |
!	                     |
!	                     |
!	                     |
!	                    st(3)
!
!
!--------------------------------------------------------------------------------
! stencil(6) is the right hand side vector component from source terms.  If
! nonzero Dirichlet boundary conditions are present, they will need to be added
! to the stencil(6) component appropriately by whoever calls this subroutine.
!--------------------------------------------------------------------------------

implicit none
public 
integer,parameter :: center=1, left=2, right=4, down=3, up=5, otherside=6

end module directions
