subroutine getparameters(meshnodes, maxits, tolerance, printfreq, nrow, ncol, nnz, printx)
!--------------------------------------------------------------------------------
! Read in the parameters that define a linear PDE and iteration controls.  
!-----------------
! Randall Bramley
! Department of Computer Science
! Indiana University, Bloomington
!--------------------------------------------------------------------------------

    use noisy
    use kindlytypes, only: int4 => integer4, int8 => integer8, real8
    use iso_fortran_env, only: stdout => output_unit, &
                               stderr => error_unit, &
                               stdin  => input_unit, &
                               iofile_end => iostat_end

    implicit none

    logical :: printx
    real(kind=real8), intent(out) :: tolerance
    integer(kind=int4), intent(out) :: maxits, printfreq
    integer(kind=int4) :: meshnodes, p, nrow, ncol, nnz
    integer(kind=int4) :: parameterfile, iostatus
    
    open(newunit=parameterfile, file='parameters', action='read', form="formatted", &
             iostat=iostatus )
    
    if (iostatus /= 0) then
        write(stderr, fmt=200) '***********************************************************'
        write(stderr, fmt=200) 'Failure in opening the parameter file. Make sure it is in'
        write(stderr, fmt=200) 'the current directory and has read permissions set.' 
        write(stderr, fmt=200) '***********************************************************'
        stop
    end if
    
    read(parameterfile, *) meshnodes, maxits, tolerance, printfreq, printx
    close(parameterfile)

    nrow = meshnodes**2
    ncol = nrow

    ! Next is for five-pt centered differences on unit square.
    nnz  = 5*ncol - 4*meshnodes

    if (benoisy > 0) then
        write(stdout,fmt=400) 'In getparameters, meshnodes = ', meshnodes
        write(stdout,fmt=400) '                  nrow = ', nrow
        write(stdout,fmt=400) '                  ncol = ', ncol
        write(stdout,fmt=400) '                  nnz = ', nnz
    end if

    if (benoisy > 1) then
        write(stdout,fmt=400) 'In getparameters, p = ', p
        write(stdout,fmt=400) '                  nrow = ', nrow
        write(stdout,fmt=400) '                  ncol = ', ncol
        write(stdout,fmt=400) '                  nnz = ', nnz
        write(stdout,fmt=400) '                  maxits = ', maxits
        write(stdout,fmt=300) '                  tolerance = ', tolerance
    end if
    if (benoisy > 0) then
        write(stdout,fmt=200) 'Returning from getparameters'
    end if

    200 format(a)
    300 format(a, es14.6)
    400 format(a, i0)
    return

end subroutine getparameters
